require "import"
import "android.content.Intent"
import "android.net.Uri"
import "android.widget.*"
import "android.view.*"
import "cjson"

local weatherApiUrl = "https://currentweather-apihubforblind.onrender.com/?city="

function handleResponse(data)
    local decodedData = cjson.decode(data)
    if decodedData and decodedData.status == 200 then
        return decodedData.message
    else
        return "Unknown Weather Data"
    end
end

layout = {
    LinearLayout;
    orientation = "vertical";
    layout_width = "match_parent";
    layout_height = "match_parent";
    backgroundColor = "#000000";
    {
        ScrollView;
        layout_width = "match_parent";
        layout_height = "0dp";
        layout_weight = "1";
        {
            LinearLayout;
            orientation = "vertical";
            layout_width = "match_parent";
            layout_height = "wrap_content";
            {
                TextView;
                id = "responseText";
                layout_width = "match_parent";
                layout_height = "wrap_content";
                text = "";
                textSize = "16sp";
                textColor = "#ffffff";
                padding = "10dp";
            };
        };
    };
    {
        EditText;
        id = "cityInput";
        hint = "Enter city name";
        layout_width = "match_parent";
        layout_height = "wrap_content";
        layout_marginBottom = "10dp";
    };
    {
        Button;
        text = "Get Weather";
        id = "searchButton";
        textColor = "#ffffff";
        backgroundColor = "#00FF00";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        onClick = function(view)
            local cityName = tostring(cityInput.getText())
            if cityName == "" then
                service.postSpeak(200, "Please enter a city name.")
                return
            end
            searchButton.setEnabled(false)
            responseText.setText("Fetching weather details...")
            service.speak("Fetching weather details...")

            local url = weatherApiUrl .. cityName
            cityInput.setText("")

            Http.get(url, function(status, data)
                searchButton.setEnabled(true)
                if status == 200 then
                    local cleanedData = handleResponse(data)
                    responseText.setText(cleanedData)
                    service.speak(cleanedData)
                else
                    responseText.setText("An error occurred while fetching weather data.")
                    service.speak("An error occurred while fetching weather data.")
                end
            end)
        end;
    };
    {
        Button;
        text = "Join Telegram Channel";
        backgroundColor = "#1E90FF";
        textColor = "#ffffff";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        onClick = function()
            local intent = Intent(Intent.ACTION_VIEW, Uri.parse("https://t.me/jieshuoofficial/"))
            this.startActivity(intent)
            dlg.dismiss()
        end
    };
    {
        Button;
        text = "Go Back";
        backgroundColor = "#000000";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        onClick = function()
            dlg.dismiss()
        end
    };
}

dlg = LuaDialog()
dlg.setTitle("Current Weather")
dlg.setView(loadlayout(layout))
dlg.show()